@@ -11,6 +11,7 @@ from .functions import (
 )
 from .listeners import coercion_listener
 from .merge import merge, Merger
+from .generic import generic_relationship
 from .proxy_dict import ProxyDict, proxy_dict
 from .types import (
     ArrowType,
@@ -37,7 +38,7 @@ from .types import (
 )
 
 
-__version__ = '0.16.9'
+__version__ = '0.16.10'
 
 
 __all__ = (
@@ -53,6 +54,7 @@ __all__ = (
     sort_query,
     table_name,
     with_backrefs,
+    generic_relationship,
     ArrowType,
     ColorType,
     CountryType,
